import time
import pytest

from najapy.cache.base import FuncCache
from najapy.common.async_base import Utils

pytestmark = pytest.mark.asyncio


class TestFuncCache:

    async def test_func_cache_1(self):
        @FuncCache(ttl=6)
        async def func_1(str1, str2, str3=None, str4=None):
            time.sleep(0.5)
            return f'{str1}-{str2}-{str3}-{str4}'

        t1 = Utils.timestamp(msec=True)
        a = await func_1('a', 'c', str3='b', str4='d')
        t2 = Utils.timestamp(msec=True)
        assert t2 - t1 >= 500

        t1 = Utils.timestamp(msec=True)
        b = await func_1('a', 'c', str3='b', str4='d')
        t2 = Utils.timestamp(msec=True)
        assert t2 - t1 < 500

        assert a == b

    async def test_func_cache_3(self):
        @FuncCache(ttl=6, includes=['str3', 'str4'])
        async def func_1(str1, str2, str3=None, str4=None):
            time.sleep(0.5)
            return f'{str1}-{str2}-{str3}-{str4}'

        t1 = Utils.timestamp(msec=True)
        a = await func_1('a', 'c', str3='b', str4='d')
        t2 = Utils.timestamp(msec=True)
        assert t2 - t1 >= 500

        t1 = Utils.timestamp(msec=True)
        b = await func_1('a', 'c', str3='b', str4='d')
        t2 = Utils.timestamp(msec=True)
        assert t2 - t1 < 500

        assert a == b

    async def test_func_cache_4(self):
        @FuncCache(ttl=6, excludes=['str3', 'str4'])
        async def func_1(str1, str2, str3=None, str4=None):
            time.sleep(0.5)
            return f'{str1}-{str2}-{str3}-{str4}'

        t1 = Utils.timestamp(msec=True)
        a = await func_1('a', 'c', str3='b', str4='d')
        t2 = Utils.timestamp(msec=True)
        assert t2 - t1 >= 500

        t1 = Utils.timestamp(msec=True)
        b = await func_1('a', 'c', str3='b', str4='d')
        t2 = Utils.timestamp(msec=True)
        assert t2 - t1 < 500

        assert a == b

    async def test_func_cache_5(self):
        @FuncCache(ttl=6, includes=['str3', 'str4'])
        async def func_1(str1, str2, str3=None, str4=None):
            time.sleep(0.5)
            return f'{str1}-{str2}-{str3}-{str4}'

        t1 = Utils.timestamp(msec=True)
        a = await func_1('a', 'c', str3='b', str4='d')
        t2 = Utils.timestamp(msec=True)
        assert t2 - t1 >= 500

        t1 = Utils.timestamp(msec=True)
        b = await func_1('a', 'c', str3='e', str4='f')
        t2 = Utils.timestamp(msec=True)
        assert t2 - t1 >= 500

        assert a != b

    async def test_func_cache_6(self):
        @FuncCache(ttl=6, excludes=['str3'])
        async def func_1(str1, str2, str3=None, str4=None):
            time.sleep(0.5)
            return f'{str1}-{str2}-{str3}-{str4}'

        t1 = Utils.timestamp(msec=True)
        a = await func_1('a', 'c', str3='b', str4='d')
        t2 = Utils.timestamp(msec=True)
        assert t2 - t1 >= 500

        t1 = Utils.timestamp(msec=True)
        b = await func_1('a', 'c', str3='b', str4='f')
        t2 = Utils.timestamp(msec=True)
        assert t2 - t1 >= 500

        assert a != b



import os
import pytest

from najapy.common.async_base import Utils

pytestmark = pytest.mark.asyncio


class TestUtils:
    _utils = Utils()

    async def test_rsa_1(self):
        text = r"这是一个测试rsa数据"

        pub_key_file_name = os.path.join(
            os.path.split(os.path.abspath(__file__))[0],
            r'test_rsa_public_key.pem'
        )
        encryption_text = self._utils.rsa_encryption(pub_key_file_name, text)

        pri_key_file_name = os.path.join(
            os.path.split(os.path.abspath(__file__))[0],
            r'test_rsa_private_key.pem'
        )
        decryption_text = self._utils.rsa_decryption(pri_key_file_name, encryption_text)

        assert decryption_text == text

    async def test_rsa_2(self):
        text = r"这是一个测试rsa数据" * 1000

        pub_key_file_name = os.path.join(
            os.path.split(os.path.abspath(__file__))[0],
            r'test_rsa_public_key.pem'
        )
        encryption_text = self._utils.rsa_encryption(pub_key_file_name, text)

        pri_key_file_name = os.path.join(
            os.path.split(os.path.abspath(__file__))[0],
            r'test_rsa_private_key.pem'
        )
        decryption_text = self._utils.rsa_decryption(pri_key_file_name, encryption_text)

        assert decryption_text == text
